oxView

Key | Action
--- | ---
P | Save image
S | Toggle selection
D | Toggle transformation
T | Translate mode
R | Rotate mode
L | Ligate
N | Nick
M | Show/Hide Menu
Right arrow | Next configuration
Left arrow | Previous configuration
Ctrl/⌘-S | Save topology and configuration
Ctrl/⌘-Z | Undo edit
Ctrl/⌘-Shift-Z (or Ctrl/⌘-Y) | Redo edit
Ctrl/⌘-A | Select all elements
Ctrl/⌘-I | Invert selection
Ctrl/⌘-click | Select multiple elements
Shift-click | Select intermediate by gid
Shift-alt-click | Select intermediate by shortest path
Ctrl/⌘-C | Copy selection
Ctrl/⌘-B | Paste selection
Ctrl/⌘-Shift-V | Paste selection in-place
Delete | Delete selected elements
Numpad0 | Reset camera
Numpad1 | Move camera to x-axis (Ctrl/⌘ to invert)
Numpad2 | Rotate camera down
Numpad3 | Move camera to y-axis (Ctrl/⌘ to invert)
Numpad4 | Rotate camera left
Numpad5 | Toggle orthographic/perspective
Numpad6 | Rotate camera right
Numpad7 | Move camera to z-axis (Ctrl/⌘ to invert)
Numpad8 | Rotate camera up
x | Shift along x-axis (with PBC)
Shift-x | Shift along negative x-axis (with PBC)
y | Shift along y-axis (with PBC)
Shift-y | Shift along negative y-axis (with PBC)
z | Shift along z-axis (with PBC)
Shift-z | Shift along negative z-axis (with PBC)

The viewer supports live relaxation using ox-serve nodes.

List of available servers:

NANOBASE.org
Pick a background color: Or upload a background image:

## Import PDB

Type a PDB identifier below to load the corresponding structure into oxView. If you already have a PDB file on your computer you can simply drag and drop it (or use the "Open" dialog).

## Import Nanobase

Type the link of a Nanobase structure to load it into oxView.

## TacoxDNA importer

Powered by tacoxDNA, you can now import common design formats.

To load oxView, oxDNA or PDB files, simply click on "Open" instead.

Select file
File format

Lattice type
Scaffold sequence Set sequence:
Default base (for single-stranded staple bases)
Tiamat version
Nucleic acid type
Default base
Scaffold sequence

Save the current stucture to oxDNA configuration and/or topology files

Please note that new nucleotide IDs will be generated in the exported files since the topology has been edited.

3D Export Options
Export format:

Material options for glTF:
Backbone metalness
Backbone roughness
Nucleoside metalness
Nucleoside roughness

File name
Faces multiplier

To hide or change the scaling of the backbones, nucleosides, etc. before export, use the "Visual Components" tool in the "View" menu.

UNF Export Options
Structure name: Author: Publication DOI:

File name
Description